@@ -17,22 +17,21 @@
 #include <config.h>
 
 #include <string.h>
+#include <glib.h>
 #include <common/macros.h>
 
 #include "red-channel-capabilities.h"
 
-GType red_channel_capabilities_type;
-
 void red_channel_capabilities_init(RedChannelCapabilities *dest,
                                    const RedChannelCapabilities *caps)
 {
     *dest = *caps;
     if (caps->common_caps) {
-        dest->common_caps = g_memdup(caps->common_caps,
+        dest->common_caps = (uint32_t*) g_memdup(caps->common_caps,
                                      caps->num_common_caps * sizeof(uint32_t));
     }
     if (caps->num_caps) {
-        dest->caps = g_memdup(caps->caps, caps->num_caps * sizeof(uint32_t));
+        dest->caps = (uint32_t*) g_memdup(caps->caps, caps->num_caps * sizeof(uint32_t));
     }
 }
 
@@ -42,24 +41,3 @@ void red_channel_capabilities_reset(RedChannelCapabilities *caps)
     g_free(caps->caps);
     memset(caps, 0, sizeof(*caps));
 }
-
-static RedChannelCapabilities *red_channel_capabilities_dup(const RedChannelCapabilities *caps)
-{
-    RedChannelCapabilities *res = g_new(RedChannelCapabilities, 1);
-    red_channel_capabilities_init(res, caps);
-    return res;
-}
-
-static void red_channel_capabilities_free(RedChannelCapabilities *caps)
-{
-    red_channel_capabilities_reset(caps);
-    g_free(caps);
-}
-
-SPICE_CONSTRUCTOR_FUNC(red_channel_capabilities_construct)
-{
-    red_channel_capabilities_type =
-        g_boxed_type_register_static("RedChannelCapabilities",
-                                     (GBoxedCopyFunc) red_channel_capabilities_dup,
-                                     (GBoxedFreeFunc) red_channel_capabilities_free);
-}
