@@ -24,7 +24,6 @@
 
 #include "red-common.h"
 #include "spice/macros.h"
-#include <common/ring.h>
 #include "basic-event-loop.h"
 
 int debug = 0;
@@ -90,6 +89,8 @@ static SpiceWatch *base_watch_add(int fd, int event_mask, SpiceWatchFunc func, v
 
 static SpiceCoreInterface core = {
     .base = {
+        .type = NULL,
+        .description = NULL,
         .major_version = SPICE_INTERFACE_CORE_MAJOR,
         .minor_version = SPICE_INTERFACE_CORE_MINOR,
     },
