@@ -165,8 +165,9 @@ static uint64_t extract_length(const uint8_t *buf, int *used)
     case LENGTH_64BIT:
         *used += 8;
         outlen = 0;
-        for (i = 56; i >= 0; i -= 8) {
-            outlen |= (*buf++) << i;
+        for (i = 0; i < 8; ++i) {
+            outlen <<= 8;
+            outlen |= *buf++;
         }
         break;
 
@@ -368,7 +369,8 @@ int websocket_read(RedsWebSocket *ws, uint8_t *buf, size_t size, unsigned *flags
             websocket_clear_frame(frame);
             send_pending_data(ws);
             return 0;
-        } else if (frame->type == BINARY_FRAME || frame->type == TEXT_FRAME) {
+        }
+        if (frame->type == BINARY_FRAME || frame->type == TEXT_FRAME) {
             rc = 0;
             if (frame->expected_len > frame->relayed) {
                 rc = ws->raw_read(ws->raw_stream, buf,
